@@ -3,8 +3,8 @@ import sys
 from json import dumps
 from json import loads
 
-from je_api_testka.utils.exception.exception_tag import cant_reformat_json_error
-from je_api_testka.utils.exception.exception_tag import wrong_json_data_error
+from je_api_testka.utils.exception.exception_tags import cant_reformat_json_error
+from je_api_testka.utils.exception.exception_tags import wrong_json_data_error
 from je_api_testka.utils.exception.exceptions import APITesterJsonException
 
 
@@ -27,6 +27,11 @@ def __process_json(json_string: str, **kwargs):
 
 
 def reformat_json(json_string: str, **kwargs):
+    """
+    :param json_string: valid json string
+    :param kwargs: indent, sort_keys or another args
+    :return: None
+    """
     try:
         return __process_json(json_string, **kwargs)
     except APITesterJsonException:
